<?php

/**
 * @Author: Khwaish Nagdev
 * @Date:   2021-03-26 11:31:59
 * @Last Modified by:   khwaish_nagdev
 * @Last Modified time: 2022-02-21 19:00:42
 */
class UpdateCallsCal {
	public function callCalendar($oCall, $events, $args) {
		
		$admin = new Administration();
		$admin->retrieveSettings();
		$enabledModules = $admin->settings['gcal_from_module'];
		$CLIENT_ID = $admin->settings['gcal_client_id'];
		$CLIENT_SECRET = $admin->settings['gcal_client_secret'];
		$modules = explode(",", $enabledModules);
		require_once 'modules/GCal/license/GCalLicense.php';
		$validate = GCalLicense::isValid('GCal');

		$gcal_enable = $admin->settings['gcal_enable'];
		
		if ($validate === true && $oCall->event_source != "gcal" && in_array("calls", $modules) && !empty($gcal_enable)) {
			global $timedate;
			$oAssignedUser = BeanFactory::getBean("Users", $oCall->assigned_user_id);
			$minutes = $timedate->getUserTimeZone($oAssignedUser);

			$time_start = strtotime('+' . $minutes['gmtOffset'] . ' minutes', strtotime($oCall->date_start));
			$time_start = date('Y-m-d H:i:s', $time_start);

			$time_end = strtotime('+' . $minutes['gmtOffset'] . ' minutes', strtotime($oCall->date_end));
			$time_end = date('Y-m-d H:i:s', $time_end);

			$time_start = str_replace(" ", "T", $time_start);
			$time_end = str_replace(" ", "T", $time_end);

			// Get event details
			$event = array();
			$event['title'] = $oCall->name;
			$event['event_time']['start_time'] = $time_start;
			$event['event_time']['end_time'] = $time_end;
			$event['event_time']['event_date'] = '';
			$event['event_time']['all_day'] = 0;
			$event['description'] = $oCall->description;
			$event['colorId'] = 11;
			$invitees = array();
			if (!empty($oCall->users_arr)) {
				foreach ($oCall->users_arr as $value) {
					$oUser = BeanFactory::getBean("Users", $value);
					if (!empty($oUser->email1)) {
						$temp = array();
						$temp['email'] = $oUser->email1;
						$temp['displayName'] = trim($oUser->first_name . ' ' . $oUser->last_name);
						$invitees[] = $temp;
						unset($temp);
					}
					unset($oUser);
				}
			}
			if (!empty($oCall->contacts_arr)) {
				foreach ($oCall->contacts_arr as $value) {
					$oContact = BeanFactory::getBean("Contacts", $value);
					if (!empty($oContact->email1)) {
						$temp = array();
						$temp['email'] = $oContact->email1;
						$temp['displayName'] = trim($oContact->first_name . ' ' . $oContact->last_name);
						$invitees[] = $temp;
						unset($temp);
					}
					unset($oContact);
				}
			}
			if (!empty($oCall->leads_arr)) {
				foreach ($oCall->leads_arr as $value) {
					$oLead = BeanFactory::getBean("Leads", $value);
					if (!empty($oLead->email1)) {
						$temp = array();
						$temp['email'] = $oLead->email1;
						$temp['displayName'] = trim($oLead->first_name . ' ' . $oLead->last_name);
						$invitees[] = $temp;
						unset($temp);
					}
					unset($oLead);
				}
			}
			
			if (!empty($oAssignedUser->gcal_auth) && !empty($oAssignedUser->gcal_calendar_id)) {
				
				header('Content-type: application/json');
				require_once 'GC/google-calendar-api.php';
				try {
					$capi = new GoogleCalendarApi();

					if (time() > $oAssignedUser->gcal_auth_expire) {
						//require_once 'GC/settings.php';
						// Get a new access token using the refresh token
						$data = $capi->GetRefreshedAccessToken($CLIENT_ID, $oAssignedUser->gcal_auth_refresh, $CLIENT_SECRET);

						// Again save the expiry time of the new token
						$oAssignedUser->gcal_auth_expire = time() + $data['expires_in'];

						// The new access token
						$oAssignedUser->gcal_auth = $data['access_token'];
						$oAssignedUser->processed = true;
						$oAssignedUser->save();
					}
					
					// Get user calendar timezone
					$user_timezone = $capi->GetUserCalendarTimezone($oAssignedUser->gcal_auth);
					if(empty($oCall->gcal_event_id)) {
						// Create event on primary calendar
						$event_id = $capi->CreateCalendarEvent($oAssignedUser->gcal_calendar_id, $event['title'], $event['all_day'], $event['event_time'], $user_timezone, $oAssignedUser->gcal_auth, $invitees, $event['colorId']);
						$oCall->gcal_event_id = $event_id;
					}
					else {
						$event_status = "confirmed";
						if($oCall->status == "Not Held")
						{
							$event_status = "cancelled";
						}
						
						$update_event = $capi->UpdateCalendarEvent($oCall->gcal_event_id,$oAssignedUser->gcal_calendar_id, $event['title'], $event['all_day'], $event['event_time'], $user_timezone, $oAssignedUser->gcal_auth,$event_status,$invitees);
					}

				} catch (Exception $e) {
					header('Bad Request', true, 400);
					$GLOBALS['log']->fatal(json_encode(array('error' => 1, 'message' => $e->getMessage())));
				}
			}
		}
	}
	public function deleteCallCalendar($oCall, $events, $args) {
		$admin = new Administration();
		$admin->retrieveSettings();
		$enabledModules = $admin->settings['gcal_from_module'];
		$modules = explode(",", $enabledModules);
		if (in_array("calls", $modules)) {
			global $timedate;
			$oAssignedUser = BeanFactory::getBean("Users", $oCall->assigned_user_id);
			if (!empty($oAssignedUser->gcal_auth) && !empty($oCall->gcal_event_id) && !empty($oAssignedUser->gcal_calendar_id)) {
				header('Content-type: application/json');
				require_once 'GC/google-calendar-api.php';
				try {
					$capi = new GoogleCalendarApi();
					
					if (time() > $oAssignedUser->gcal_auth_expire) {
						//require_once 'GC/settings.php';
						// Get a new access token using the refresh token
						$data = $capi->GetRefreshedAccessToken($CLIENT_ID, $oAssignedUser->gcal_auth_refresh, $CLIENT_SECRET);

						// Again save the expiry time of the new token
						$oAssignedUser->gcal_auth_expire = time() + $data['expires_in'];

						// The new access token
						$oAssignedUser->gcal_auth = $data['access_token'];
						$oAssignedUser->processed = true;
						$oAssignedUser->save();
					}

					// Get user calendar timezone
					$user_timezone = $capi->GetUserCalendarTimezone($oAssignedUser->gcal_auth);

					// delete event from calendar
					$deleteEvent = $capi->DeleteCalendarEvent($oCall->gcal_event_id, $oAssignedUser->gcal_calendar_id, $oAssignedUser->gcal_auth);

				} catch (Exception $e) {
					header('Bad Request', true, 400);
					$GLOBALS['log']->fatal(json_encode(array('error' => 1, 'message' => $e->getMessage())));
				}
			}
		}
	}
}