<?php

class GoogleCalendarApi {
	public function GetAccessToken($client_id, $redirect_uri, $client_secret, $code) {
		$url = 'https://accounts.google.com/o/oauth2/token';

		$curlPost = 'client_id=' . $client_id . '&redirect_uri=' . $redirect_uri . '&client_secret=' . $client_secret . '&code=' . $code . '&grant_type=authorization_code';
		$ch = curl_init();
		curl_setopt($ch, CURLOPT_URL, $url);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
		curl_setopt($ch, CURLOPT_POST, 1);
		curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, FALSE);
		curl_setopt($ch, CURLOPT_POSTFIELDS, $curlPost);
		$data = json_decode(curl_exec($ch), true);
		$http_code = curl_getinfo($ch, CURLINFO_HTTP_CODE);
		if ($http_code != 200) {
			throw new Exception('Error : Failed to receieve access token');
		}

		return $data;
	}

	public function GetUserCalendarTimezone($access_token) {

		$url_settings = 'https://www.googleapis.com/calendar/v3/users/me/settings/timezone';

		$ch = curl_init();
		curl_setopt($ch, CURLOPT_URL, $url_settings);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
		curl_setopt($ch, CURLOPT_HTTPHEADER, array('Authorization: Bearer ' . $access_token));
		curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, FALSE);
		$data = json_decode(curl_exec($ch), true);

		$http_code = curl_getinfo($ch, CURLINFO_HTTP_CODE);

		if ($http_code != 200) {
			throw new Exception('Error : Failed to get timezone');
		}

		return $data['value'];
	}

	public function GetCalendarsList($access_token) {
		$url_parameters = array();

		$url_parameters['fields'] = 'items(id,summary,timeZone)';
		$url_parameters['minAccessRole'] = 'owner';

		//$url_calendars = 'https://www.googleapis.com/calendar/v3/users/me/calendarList?' . http_build_query($url_parameters);
		$url_calendars = 'https://www.googleapis.com/calendar/v3/users/me/calendarList';
		$ch = curl_init();
		curl_setopt($ch, CURLOPT_URL, $url_calendars);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
		curl_setopt($ch, CURLOPT_HTTPHEADER, array('Authorization: Bearer ' . $access_token));
		curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, FALSE);
		$data = json_decode(curl_exec($ch), true);

		$http_code = curl_getinfo($ch, CURLINFO_HTTP_CODE);
		if ($http_code != 200) {
			throw new Exception('Error : Failed to get calendars list');
		}

		return $data['items'];
	}

	public function GetCalendarEvents($access_token, $calenderId, $time) {
		$url_parameters = array();

		$url_parameters['timeMin'] = $time;
		$url_parameters['maxResults'] = 10;
		$url_parameters['singleEvents'] = "true";
		//$url_parameters['orderBy'] = 'updated';
		$url_settings = 'https://www.googleapis.com/calendar/v3/calendars/' . $calenderId . '/events?' . http_build_query($url_parameters);

		$ch = curl_init();
		curl_setopt($ch, CURLOPT_URL, $url_settings);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
		curl_setopt($ch, CURLOPT_HTTPHEADER, array('Authorization: Bearer ' . $access_token));
		curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, FALSE);
		$data = json_decode(curl_exec($ch), true);

		$http_code = curl_getinfo($ch, CURLINFO_HTTP_CODE);

		if ($http_code != 200) {
			throw new Exception('Error : Failed to get calendar events');
		}

		return $data['items'];
	}

	public function CreateCalendarEvent($calendar_id, $summary, $all_day, $event_time, $event_timezone, $access_token, $invitees, $colorId) {
		$url_parameters = array();
		$url_parameters['sendUpdates'] = 'all';
		$url_parameters['sendNotifications'] = "true";
		$url_events = 'https://www.googleapis.com/calendar/v3/calendars/' . $calendar_id . '/events?' . http_build_query($url_parameters);
		$curlPost = array('summary' => $summary);
		if ($all_day == 1) {
			$curlPost['start'] = array('date' => $event_time['event_date']);
			$curlPost['end'] = array('date' => $event_time['event_date']);
		} else {
			$curlPost['start'] = array('dateTime' => $event_time['start_time'], 'timeZone' => $event_timezone);
			$curlPost['end'] = array('dateTime' => $event_time['end_time'], 'timeZone' => $event_timezone);
		}
		if (!empty($invitees)) {
			$curlPost['attendees'] = $invitees;
			$curlPost['sendUpdates'] = "all";
			$curlPost['sendNotifications'] = TRUE;
			$curlPost['reminders'] = array(
				'useDefault' => TRUE,
				/*'overrides' => array(
					array('method' => 'email', 'minutes' => 24 * 60),
					array('method' => 'popup', 'minutes' => 30),
				),*/
			);
		}
		if (!empty($colorId)) {
			$curlPost['colorId'] = $colorId;
		}

		$ch = curl_init();
		curl_setopt($ch, CURLOPT_URL, $url_events);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
		curl_setopt($ch, CURLOPT_POST, 1);
		curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, FALSE);
		curl_setopt($ch, CURLOPT_HTTPHEADER, array('Authorization: Bearer ' . $access_token, 'Content-Type: application/json'));
		curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($curlPost));
		$data = json_decode(curl_exec($ch), true);
		$http_code = curl_getinfo($ch, CURLINFO_HTTP_CODE);

		if ($http_code != 200) {
			throw new Exception('Error : Failed to create event');
		}

		return $data['id'];
	}
	public function GetRefreshedAccessToken($client_id, $refresh_token, $client_secret) {
		$url_token = 'https://www.googleapis.com/oauth2/v4/token';
		$curlPost = 'client_id=' . $client_id . '&client_secret=' . $client_secret . '&refresh_token=' . $refresh_token . '&grant_type=refresh_token';
		$ch = curl_init();
		curl_setopt($ch, CURLOPT_URL, $url_token);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
		curl_setopt($ch, CURLOPT_POST, 1);
		curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, FALSE);
		curl_setopt($ch, CURLOPT_POSTFIELDS, $curlPost);
		$data = json_decode(curl_exec($ch), true); //print_r($data);
		$http_code = curl_getinfo($ch, CURLINFO_HTTP_CODE);
		if ($http_code != 200) {
			throw new Exception('Error : Failed to refresh access token');
		}
		return $data;
	}
	public function DeleteCalendarEvent($event_id, $calendar_id, $access_token) {
		$url_events = 'https://www.googleapis.com/calendar/v3/calendars/' . $calendar_id . '/events/' . $event_id;

		$ch = curl_init();
		curl_setopt($ch, CURLOPT_URL, $url_events);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
		curl_setopt($ch, CURLOPT_CUSTOMREQUEST, 'DELETE');
		curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, FALSE);
		curl_setopt($ch, CURLOPT_HTTPHEADER, array('Authorization: Bearer ' . $access_token, 'Content-Type: application/json'));
		$data = json_decode(curl_exec($ch), true);
		$http_code = curl_getinfo($ch, CURLINFO_HTTP_CODE);
		if ($http_code != 204) {
			throw new Exception('Error : Failed to delete event');
		}

	}
	public function UpdateCalendarEvent($event_id, $calendar_id, $summary, $all_day, $event_time, $event_timezone, $access_token,$status,$invitees) {
		$url_events = 'https://www.googleapis.com/calendar/v3/calendars/' . $calendar_id . '/events/' . $event_id;

		$curlPost = array('summary' => $summary);
		if ($all_day == 1) {
			$curlPost['start'] = array('date' => $event_time['event_date']);
			$curlPost['end'] = array('date' => $event_time['event_date']);
		} else {
			$curlPost['start'] = array('dateTime' => $event_time['start_time'], 'timeZone' => $event_timezone);
			$curlPost['end'] = array('dateTime' => $event_time['end_time'], 'timeZone' => $event_timezone);
		}
		if (!empty($invitees)) {
			$curlPost['attendees'] = $invitees;
			$curlPost['sendUpdates'] = "all";
			$curlPost['sendNotifications'] = TRUE;
			$curlPost['reminders'] = array(
				'useDefault' => TRUE,
				/*'overrides' => array(
					array('method' => 'email', 'minutes' => 24 * 60),
					array('method' => 'popup', 'minutes' => 30),
				),*/
			);
		}
		$curlPost['status'] = $status;
		$ch = curl_init();
		curl_setopt($ch, CURLOPT_URL, $url_events);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
		curl_setopt($ch, CURLOPT_CUSTOMREQUEST, 'PUT');
		curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, FALSE);
		curl_setopt($ch, CURLOPT_HTTPHEADER, array('Authorization: Bearer ' . $access_token, 'Content-Type: application/json'));
		curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($curlPost));
		$data = json_decode(curl_exec($ch), true);
		$http_code = curl_getinfo($ch, CURLINFO_HTTP_CODE);
		if ($http_code != 200) {
			throw new Exception('Error : Failed to update event');
		}

	}
	public function CreateCalendar($access_token, $title, $timezone) {
		$url_calendar = 'https://content.googleapis.com/calendar/v3/calendars?alt=json';

		$curlPost = array('summary' => $title, "timeZone" => $timezone);
		$curlPost['conferenceProperties'] = array('allowedConferenceSolutionTypes' => array('hangoutsMeet'));
		$ch = curl_init();
		curl_setopt($ch, CURLOPT_URL, $url_calendar);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
		curl_setopt($ch, CURLOPT_CUSTOMREQUEST, 'POST');
		curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, FALSE);
		curl_setopt($ch, CURLOPT_HTTPHEADER, array('Authorization: Bearer ' . $access_token, 'Content-Type: application/json'));
		curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($curlPost));
		$data = json_decode(curl_exec($ch), true);
		$http_code = curl_getinfo($ch, CURLINFO_HTTP_CODE);
		if ($http_code != 200) {
			throw new Exception('Error : Failed to create calendar');
		}
		return $data;
	}
	public function UpdateCalendar($access_token, $title, $calendarId, $timezone) {

		$url_calendar = 'https://www.googleapis.com/calendar/v3/calendars/' . $calendarId;

		$curlPost = array('summary' => $title, "timeZone" => $timezone);
		$curlPost['conferenceProperties'] = array('allowedConferenceSolutionTypes' => array('hangoutsMeet'));

		$ch = curl_init();
		curl_setopt($ch, CURLOPT_URL, $url_calendar);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
		curl_setopt($ch, CURLOPT_CUSTOMREQUEST, 'PUT');
		curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, FALSE);
		curl_setopt($ch, CURLOPT_HTTPHEADER, array('Authorization: Bearer ' . $access_token, 'Content-Type: application/json'));
		curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($curlPost));
		$data = json_decode(curl_exec($ch), true);
		$http_code = curl_getinfo($ch, CURLINFO_HTTP_CODE);
		if ($http_code != 200) {
			throw new Exception('Error : Failed to create calendar');
		}
		return $data;
	}
	public function DeleteCalendar($access_token, $calendarId) {
		$url_calendar = 'https://www.googleapis.com/calendar/v3/calendars/' . $calendarId;
		$ch = curl_init();
		curl_setopt($ch, CURLOPT_URL, $url_calendar);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
		curl_setopt($ch, CURLOPT_CUSTOMREQUEST, 'DELETE');
		curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, FALSE);
		curl_setopt($ch, CURLOPT_HTTPHEADER, array('Authorization: Bearer ' . $access_token, 'Content-Type: application/json'));
		$data = json_decode(curl_exec($ch), true);
		$http_code = curl_getinfo($ch, CURLINFO_HTTP_CODE);
		if ($http_code != 200) {
			throw new Exception('Error : Failed to create calendar');
		}
		return $data;
	}
	public function getCalendarEventUpdate($calendarId,$eventId,$access_token) {
		$url_events = 'https://www.googleapis.com/calendar/v3/calendars/' . $calendarId . '/events/' . $eventId;
		echo $url_events;
		$curlPost = array();
		
		$ch = curl_init();
		curl_setopt($ch, CURLOPT_URL, $url_events);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
		curl_setopt($ch, CURLOPT_CUSTOMREQUEST, 'GET');
		curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, FALSE);
		curl_setopt($ch, CURLOPT_HTTPHEADER, array('Authorization: Bearer ' . $access_token, 'Content-Type: application/json'));
		$data = json_decode(curl_exec($ch), true);
		$http_code = curl_getinfo($ch, CURLINFO_HTTP_CODE);
		if ($http_code != 200) {
			throw new Exception('Error : Failed to get event');
		}
		return $data;
	}
}

?>