<?php

/**
 * @Author: Khwaish Nagdev
 * @Date:   2021-03-17 18:37:02
 * @Last Modified by:   khwaish_nagdev
 * @Last Modified time: 2022-02-21 19:00:58
 */
class UpdateMeetingsCal {
	public function meetingCalendar($oMeeting, $events, $args) {
		$admin = new Administration();
		$admin->retrieveSettings();
		$enabledModules = $admin->settings['gcal_from_module'];
		$CLIENT_ID = $admin->settings['gcal_client_id'];
		$CLIENT_SECRET = $admin->settings['gcal_client_secret'];
		$modules = explode(",", $enabledModules);
		require_once 'modules/GCal/license/GCalLicense.php';
		$validate = GCalLicense::isValid('GCal');
		$gcal_enable = $admin->settings['gcal_enable'];
		if (!empty($gcal_enable) && $validate === true && $oMeeting->event_source != "gcal" && in_array("meetings", $modules)) {
			global $timedate;

			$oAssignedUser = BeanFactory::getBean("Users", $oMeeting->assigned_user_id);
			$minutes = $timedate->getUserTimeZone($oAssignedUser);

			$time_start = strtotime('+' . $minutes['gmtOffset'] . ' minutes', strtotime($oMeeting->date_start));
			$time_start = date('Y-m-d H:i:s', $time_start);

			$time_end = strtotime('+' . $minutes['gmtOffset'] . ' minutes', strtotime($oMeeting->date_end));
			$time_end = date('Y-m-d H:i:s', $time_end);

			$time_start = str_replace(" ", "T", $time_start);
			$time_end = str_replace(" ", "T", $time_end);

			// Get event details
			$event = array();
			$event['title'] = $oMeeting->name;
			$event['event_time']['start_time'] = $time_start;
			$event['event_time']['end_time'] = $time_end;
			$event['event_time']['event_date'] = '';
			$event['event_time']['all_day'] = 0;
			$event['description'] = $oMeeting->description;
			$event['colorId'] = 6;
			$invitees = array();
			if (!empty($oMeeting->users_arr)) {
				foreach ($oMeeting->users_arr as $value) {
					$oUser = BeanFactory::getBean("Users", $value);
					if (!empty($oUser->email1)) {
						$temp = array();
						$temp['email'] = $oUser->email1;
						$temp['displayName'] = trim($oUser->first_name . ' ' . $oUser->last_name);
						$invitees[] = $temp;
						unset($temp);
					}
					unset($oUser);
				}
			}
			if (!empty($oMeeting->contacts_arr)) {
				foreach ($oMeeting->contacts_arr as $value) {
					$oContact = BeanFactory::getBean("Contacts", $value);
					if (!empty($oContact->email1)) {
						$temp = array();
						$temp['email'] = $oContact->email1;
						$temp['displayName'] = trim($oContact->first_name . ' ' . $oContact->last_name);
						$invitees[] = $temp;
						unset($temp);
					}
					unset($oContact);
				}
			}
			if (!empty($oMeeting->leads_arr)) {
				foreach ($oMeeting->leads_arr as $value) {
					$oLead = BeanFactory::getBean("Leads", $value);
					if (!empty($oLead->email1)) {
						$temp = array();
						$temp['email'] = $oLead->email1;
						$temp['displayName'] = trim($oLead->first_name . ' ' . $oLead->last_name);
						$invitees[] = $temp;
						unset($temp);
					}
					unset($oLead);
				}
			}

			if (!empty($oAssignedUser->gcal_auth) && !empty($oAssignedUser->gcal_calendar_id)) {
				header('Content-type: application/json');
				require_once 'GC/google-calendar-api.php';
				try {
					$capi = new GoogleCalendarApi();

					if (time() > $oAssignedUser->gcal_auth_expire) {
						//require_once 'GC/settings.php';
						// Get a new access token using the refresh token
						$data = $capi->GetRefreshedAccessToken($CLIENT_ID, $oAssignedUser->gcal_auth_refresh, $CLIENT_SECRET);

						// Again save the expiry time of the new token
						$oAssignedUser->gcal_auth_expire = time() + $data['expires_in'];

						// The new access token
						$oAssignedUser->gcal_auth = $data['access_token'];
						$oAssignedUser->processed = true;
						$oAssignedUser->save();
					}

					// Get user calendar timezone
					$user_timezone = $capi->GetUserCalendarTimezone($oAssignedUser->gcal_auth);
					if(empty($oMeeting->gcal_event_id) && $oMeeting->status == "Planned") {
						// Create event on primary calendar
						$event_id = $capi->CreateCalendarEvent($oAssignedUser->gcal_calendar_id, $event['title'], $event['all_day'], $event['event_time'], $user_timezone, $oAssignedUser->gcal_auth, $invitees, $event['colorId']);
						$oMeeting->gcal_event_id = $event_id;
					}
					else{
						$event_status = "confirmed";
						if($oMeeting->status == "Not Held")
						{
							$event_status = "cancelled";
						}
						$update_event = $capi->UpdateCalendarEvent($oMeeting->gcal_event_id,$oAssignedUser->gcal_calendar_id, $event['title'], $event['all_day'], $event['event_time'], $user_timezone, $oAssignedUser->gcal_auth,$event_status,$invitees);
					}
					

				} catch (Exception $e) {
					//header('Bad Request', true, 400);
					$GLOBALS['log']->fatal(json_encode(array('error' => 1, 'message' => $e->getMessage())));
				}
			}
		}
	}
	public function deleteMeetingCalendar($oMeeting, $events, $args) {
		$admin = new Administration();
		$admin->retrieveSettings();
		$enabledModules = $admin->settings['gcal_from_module'];
		$modules = explode(",", $enabledModules);
		if (in_array("meetings", $modules)) {
			$oAssignedUser = BeanFactory::getBean("Users", $oMeeting->assigned_user_id);
			require_once 'GC/google-calendar-api.php';
			try {
				$capi = new GoogleCalendarApi();

				if (time() > $oAssignedUser->gcal_auth_expire) {
					//require_once 'GC/settings.php';
					// Get a new access token using the refresh token
					$data = $capi->GetRefreshedAccessToken($CLIENT_ID, $oAssignedUser->gcal_auth_refresh, $CLIENT_SECRET);

					// Again save the expiry time of the new token
					$oAssignedUser->gcal_auth_expire = time() + $data['expires_in'];

					// The new access token
					$oAssignedUser->gcal_auth = $data['access_token'];
					$oAssignedUser->processed = true;
					$oAssignedUser->save();
				}

				// Get user calendar timezone
				$user_timezone = $capi->GetUserCalendarTimezone($oAssignedUser->gcal_auth);
				// delete calebdar event
				$deleteEvent = $capi->DeleteCalendarEvent($oMeeting->gcal_event_id, $oAssignedUser->gcal_calendar_id, $oAssignedUser->gcal_auth);

			} catch (Exception $e) {
				//header('Bad Request', true, 400);
				$GLOBALS['log']->fatal(json_encode(array('error' => 1, 'message' => $e->getMessage())));
			}

		}
	}
}